

### Added
- `use_instance_space` option to write validation records into the validated instance's space
- `records_space` override in view YAML records config

### Changed
- Updated readthedocs: removed cog-sail refs, clarified local vs CDF Function execution